import { AfterViewInit, ApplicationRef, ComponentFactoryResolver, EventEmitter, Injector, OnDestroy, Renderer2, TemplateRef } from '@angular/core';
import { Subject } from 'rxjs';
import { WalkthroughContainerComponent } from './walkthrough-container.component';
import { WalkthroughTextI } from './walkthrough-text';
import { WalkthroughEvent } from './walkthrough-tools';
import { WalkthroughService } from './walkthrough.service';
import * as i0 from "@angular/core";
export interface WalkthroughNavigate {
    previous: WalkthroughComponent;
    next: WalkthroughComponent;
}
export declare class WalkthroughComponent implements AfterViewInit, OnDestroy {
    private _componentFactoryResolver;
    private _applicationRef;
    private _injector;
    private _renderer;
    private _walkthroughService;
    private static _walkthroughContainer;
    private static _walkthroughContainerCreating;
    static minimalMargin: number;
    static onOpen: Subject<WalkthroughComponent>;
    static onRefresh: Subject<WalkthroughComponent>;
    static onClose: Subject<WalkthroughComponent>;
    static onNavigate: Subject<WalkthroughNavigate>;
    static onNavigatePrevious: Subject<WalkthroughNavigate>;
    static onNavigateNext: Subject<WalkthroughNavigate>;
    static onFinish: Subject<WalkthroughComponent>;
    closed: EventEmitter<boolean>;
    finished: EventEmitter<WalkthroughEvent>;
    ready: EventEmitter<WalkthroughEvent>;
    focusElementCSSClass: string;
    rootElement: string;
    focusElementSelector: string;
    typeSelector: 'element' | 'zone';
    focusClick: (event: Event, content: WalkthroughContainerComponent) => void;
    radius: string;
    previousStep: WalkthroughComponent;
    nextStep: WalkthroughComponent;
    texts: WalkthroughTextI;
    contentTemplate: TemplateRef<any>;
    contentText: string;
    contentStyle: 'none' | 'darken';
    observerOptions: MutationObserverInit;
    get marginZone(): string | null;
    set marginZone(points: string | null);
    get arrowColor(): string;
    set arrowColor(color: string);
    animation: 'none' | 'linear';
    animationDelays: number;
    get notScrollOnResize(): string | boolean;
    set notScrollOnResize(value: string | boolean);
    get id(): string;
    set id(value: string);
    get alignContent(): 'left' | 'center' | 'content' | 'right';
    set alignContent(value: 'left' | 'center' | 'content' | 'right');
    get verticalAlignContent(): 'above' | 'top' | 'center' | 'bottom' | 'below';
    set verticalAlignContent(value: 'above' | 'top' | 'center' | 'bottom' | 'below');
    get contentSpacing(): number;
    set contentSpacing(value: number);
    get verticalContentSpacing(): number;
    set verticalContentSpacing(value: number);
    get closeButton(): string | boolean;
    set closeButton(value: string | boolean);
    get closeAnywhere(): string | boolean;
    set closeAnywhere(value: string | boolean);
    get showArrow(): string | boolean;
    set showArrow(value: string | boolean);
    get finishButton(): string | boolean;
    set finishButton(value: string | boolean);
    get focusHighlightAnimation(): string | boolean;
    set focusHighlightAnimation(value: string | boolean);
    get focusBackdrop(): string | boolean;
    set focusBackdrop(value: string | boolean);
    get focusGlow(): string | boolean;
    set focusGlow(value: string | boolean);
    get disabled(): boolean;
    set disabled(value: boolean);
    get hidePrevious(): string | boolean;
    set hidePrevious(value: string | boolean);
    get hideNext(): string | boolean;
    set hideNext(value: string | boolean);
    get hideNav(): string | boolean;
    set hideNav(value: string | boolean);
    scrollOnTarget: boolean;
    visibilityCallback: () => boolean;
    private _id;
    private _uid;
    private _readyHasBeenEmitted;
    private _display;
    private _hasHighlightAnimation;
    private _hasBackdrop;
    private _hasGlow;
    private _hasFinish;
    private _hasArrow;
    private _hasCloseButton;
    private _hasCloseAnywhere;
    private _disabled;
    private _hidePrevious;
    private _hideNext;
    private _hideNav;
    private _arrowColor;
    private _marginZone;
    private _marginZonePx;
    private _alignContent;
    private _verticalAlignContent;
    private _contentSpacing;
    private _verticalContentSpacing;
    private _focusElement;
    private _focusElementEnd;
    /** target coordinates */
    private _offsetCoordinates;
    private _onContainerInit;
    private _onResize;
    private _notScrollOnResize;
    private _resizeDelays;
    private _domChangedObserver;
    static walkthroughStop(): void;
    static walkthroughHasShow(): boolean;
    static walkthroughHasPause(): boolean;
    static walkthroughContinue(): void;
    static walkthroughNext(): void;
    static walkthroughPrevious(): void;
    constructor(_componentFactoryResolver: ComponentFactoryResolver, _applicationRef: ApplicationRef, _injector: Injector, _renderer: Renderer2, _walkthroughService: WalkthroughService);
    resize(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    next(closedEvent?: EventEmitter<boolean>, finishedEvent?: EventEmitter<WalkthroughEvent>): void;
    refresh(): void;
    open(): Promise<boolean>;
    /**
     * Do not use this method outside of the library
     */
    _loadPreviousStep(): void;
    /**
     * Do not use this method outside of the library
     */
    loadNextStep(): void;
    /**
     * Do not use this method outside of the library
     */
    _hide(finishLink?: boolean, closeWalkthrough?: boolean, triggerFinishIfEnd?: boolean): void;
    private _checkVisibility;
    private _open;
    private _show;
    private _next;
    private _getInstance;
    private _appendComponentToBody;
    private _attachWalkthroughContent;
    private _elementLocations;
    private _close;
    private _hasElements;
    private _getFocusElements;
    private _getFocusElement;
    /**
     * get instance, highlight the focused element et show the template
     */
    private _setFocus;
    private _setFocusContinue;
    private _updateElementPositions;
    /**
     * Attache the template in the container, if a template is linked.
     */
    private _attachContentTemplate;
    /**
     * init a part of styles of the container
     */
    private _initStylingTemplate;
    /**
     * init all datas of the container
     */
    private _initContentTemplate;
    /**
     * check if there is a previous step enabled
     */
    private _hasPreviousStep;
    /**
     * check if there is a next step enabled
     */
    private _hasNextStep;
    static ɵfac: i0.ɵɵFactoryDeclaration<WalkthroughComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WalkthroughComponent, "ng-walkthrough", never, { "focusElementCSSClass": { "alias": "focusElementCSSClass"; "required": false; }; "rootElement": { "alias": "rootElement"; "required": false; }; "focusElementSelector": { "alias": "focusElementSelector"; "required": false; }; "typeSelector": { "alias": "typeSelector"; "required": false; }; "focusClick": { "alias": "focusClick"; "required": false; }; "radius": { "alias": "radius"; "required": false; }; "previousStep": { "alias": "previousStep"; "required": false; }; "nextStep": { "alias": "nextStep"; "required": false; }; "texts": { "alias": "texts"; "required": false; }; "contentTemplate": { "alias": "contentTemplate"; "required": false; }; "contentText": { "alias": "contentText"; "required": false; }; "contentStyle": { "alias": "contentStyle"; "required": false; }; "observerOptions": { "alias": "observerOptions"; "required": false; }; "marginZone": { "alias": "marginZone"; "required": false; }; "arrowColor": { "alias": "arrowColor"; "required": false; }; "animation": { "alias": "animation"; "required": false; }; "animationDelays": { "alias": "animationDelays"; "required": false; }; "notScrollOnResize": { "alias": "notScrollOnResize"; "required": false; }; "id": { "alias": "id"; "required": false; }; "alignContent": { "alias": "alignContent"; "required": false; }; "verticalAlignContent": { "alias": "verticalAlignContent"; "required": false; }; "contentSpacing": { "alias": "contentSpacing"; "required": false; }; "verticalContentSpacing": { "alias": "verticalContentSpacing"; "required": false; }; "closeButton": { "alias": "closeButton"; "required": false; }; "closeAnywhere": { "alias": "closeAnywhere"; "required": false; }; "showArrow": { "alias": "showArrow"; "required": false; }; "finishButton": { "alias": "finishButton"; "required": false; }; "focusHighlightAnimation": { "alias": "focusHighlightAnimation"; "required": false; }; "focusBackdrop": { "alias": "focusBackdrop"; "required": false; }; "focusGlow": { "alias": "focusGlow"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "hidePrevious": { "alias": "hidePrevious"; "required": false; }; "hideNext": { "alias": "hideNext"; "required": false; }; "hideNav": { "alias": "hideNav"; "required": false; }; "scrollOnTarget": { "alias": "scrollOnTarget"; "required": false; }; "visibilityCallback": { "alias": "visibilityCallback"; "required": false; }; }, { "closed": "closed"; "finished": "finished"; "ready": "ready"; }, never, never, false, never>;
}
//# sourceMappingURL=walkthrough.component.d.ts.map